PageType class

Properties

hashCode int
The hash code for this object.
no setterinherited
pType String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

categoryPage → const PageType
contentPage → const PageType
conversion → const PageType
homePage → const PageType
otherPage → const PageType
productPage → const PageType
searchPage → const PageType
thematicPage → const PageType