PixelTracker class

Constructors

PixelTracker()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

addToCartEventPixel(String ref, String title, String prodId, String prodName, String sku, {String? prodCollectionId}) → void
categoryPageViewPixel(String ref, String title, String categoryId, String category) → void
contentPageViewPixel(String ref, String title, List<CatalogItem> catalogs, String itemId, String itemName) → void
contentSearchPageViewPixel(String ref, String title, List<CatalogItem> catalogs, String searchTerm) → void
conversionPageView(String ref, String title, bool isConversion, String basketValue, String orderId, List<PixelBasketItem> basket) → void
customEventPixel(String ref, String title, String eType, PageType pType, GroupType group, Map<String, String?> params) → void
customPageViewPixel(String ref, String title, PageType pType, Map<String, String?> params) → void
homePageViewPixel(String ref, String title) → void
init(BrPixel brPixel) → void
otherPageViewPixel(String ref, String title) → void
pageViewPixel(String ref, String title) → void
productPageViewPixel(String ref, String title, String prodId, String prodName, {String? sku, String? brPSuggQ}) → void
quickViewEventPixel(String ref, String title, String prodId, String prodName, String sku) → void
searchEventPixel(String ref, String title, String searchTerm, {List<CatalogItem>? catalogs}) → void
searchResultPageViewPixel(String ref, String title, String searchTerm) → void
suggestionEventPixel(String ref, String title, String typedTerm, String searchTerm, {List<CatalogItem>? catalogs}) → void
widgetAddToCart(String widgetDataWrId, String widgetViewDataWid, String widgetViewDataWq, String widgetViewDataWty, String widgetDataItemId, {String? widgetAtcDataSku}) → void
widgetClick(String widgetDataWrId, String widgetViewDataWq, String widgetViewDataWid, String widgetViewDataWty, String widgetDataItemId) → void
widgetView(String widgetDataWrId, String widgetViewDataWq, String widgetViewDataWid, String widgetViewDataWty) → void