fields property

Map<String, dynamic> fields
final

Dynamic fields map containing all product data returned by the API Structure depends on the fl parameter in the search request

Implementation

final Map<String, dynamic> fields;