SearchResponseGroupResponseGroupList class

Constructors

SearchResponseGroupResponseGroupList({required double matches, List<SearchResponseGroupResponseGroupListGroup> groups = const []})
Returns a new SearchResponseGroupResponseGroupList instance.

Properties

groups List<SearchResponseGroupResponseGroupListGroup>
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
matches double
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) SearchResponseGroupResponseGroupList?
Returns a new SearchResponseGroupResponseGroupList instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<SearchResponseGroupResponseGroupList>
mapFromJson(dynamic json) Map<String, SearchResponseGroupResponseGroupList>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<SearchResponseGroupResponseGroupList>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.