SearchResponseGroupResponseGroupListGroup class
Constructors
- SearchResponseGroupResponseGroupListGroup({String? groupValue, SearchResponseGroupResponseGroupListGroupDoclist? doclist})
- Returns a new SearchResponseGroupResponseGroupListGroup instance.
Properties
- doclist ↔ SearchResponseGroupResponseGroupListGroupDoclist?
-
getter/setter pair
- groupValue ↔ String?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → SearchResponseGroupResponseGroupListGroup? -
Returns a new SearchResponseGroupResponseGroupListGroup instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< SearchResponseGroupResponseGroupListGroup> -
mapFromJson(
dynamic json) → Map< String, SearchResponseGroupResponseGroupListGroup> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< SearchResponseGroupResponseGroupListGroup> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.