SearchResponseGroupResponseGroupListGroupDoclist class

Constructors

SearchResponseGroupResponseGroupListGroupDoclist({List<SearchResponseDoc> docs = const [], double? maxScore, double? numFound, double? start})
Returns a new SearchResponseGroupResponseGroupListGroupDoclist instance.

Properties

docs List<SearchResponseDoc>
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
maxScore double?
getter/setter pair
numFound double?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start double?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) SearchResponseGroupResponseGroupListGroupDoclist?
Returns a new SearchResponseGroupResponseGroupListGroupDoclist instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<SearchResponseGroupResponseGroupListGroupDoclist>
mapFromJson(dynamic json) Map<String, SearchResponseGroupResponseGroupListGroupDoclist>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<SearchResponseGroupResponseGroupListGroupDoclist>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.