SearchResponseKeywords class
Constructors
- SearchResponseKeywords({String? originalQuery, String? redirectedQuery, String? redirectedUrl})
- Returns a new SearchResponseKeywords instance.
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- originalQuery ↔ String?
-
getter/setter pair
- redirectedQuery ↔ String?
-
getter/setter pair
- redirectedUrl ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → SearchResponseKeywords? -
Returns a new SearchResponseKeywords instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< SearchResponseKeywords> -
mapFromJson(
dynamic json) → Map< String, SearchResponseKeywords> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< SearchResponseKeywords> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.